@@ -1,6 +1,6 @@
 #include<stdexcept>
-#include<yade/core/Material.hpp>
-#include<yade/core/Scene.hpp>
+#include<core/Material.hpp>
+#include<core/Scene.hpp>
 
 const shared_ptr<Material> Material::byId(int id, Scene* w_){
 	Scene* w=w_?w_:Omega::instance().getScene().get();
