@@ -17,7 +17,10 @@ void SimulationFlow::singleAction()
 {
 	Scene* scene=Omega::instance().getScene().get();
 	if (!scene) throw logic_error("SimulationFlow::singleAction: no Scene object?!");
-	if(scene->subStepping) { LOG_INFO("Sub-stepping disabled when running simulation continuously."); scene->subStepping=false; }
+	if(scene->subStepping) { 
+		LOG_INFO("Sub-stepping disabled when running simulation continuously.");
+		scene->subStepping=false;
+	}
 	scene->moveToNextTimeStep();
 	if(scene->stopAtIter>0 && scene->iter==scene->stopAtIter) setTerminate(true);
 	if(scene->stopAtTime>0 && scene->time==scene->stopAtTime) setTerminate(true);
