@@ -63,6 +63,9 @@ class State: public Serializable, public Indexable{
 #ifdef YADE_LIQMIGRATION
 		((Real,Vf, 0.0,,   "Individual amount of liquid"))
 		((Real,Vmin, 0.0,, "Minimal amount of liquid"))
+#endif
+#ifdef YADE_DEFORM
+		((Real,dR, 0.0,,   "Sphere deformation"))
 #endif
 		,
 		/* additional initializers */
