@@ -39,8 +39,8 @@ triax=TriaxialCompressionEngine(
 	wall_back_id=wallIds[4],
 	wall_front_id=wallIds[5],
 	internalCompaction=False,
-	sigmaIsoCompaction=50e3,
-	sigmaLateralConfinement=50e3,
+	sigmaIsoCompaction=-50e3,
+	sigmaLateralConfinement=-50e3,
 	strainRate=0.02,
 	frictionAngleDegree=30,
 	StabilityCriterion = 0.01,
