@@ -1,5 +1,5 @@
-from yade import utils,pack,timing
-#O.bodies.append([	utils.sphere((0.2,0,0),.5,fixed=True), utils.sphere((0.2,0.0,1.01),.5), ])
+from yade import pack,timing
+#O.bodies.append([	sphere((0.2,0,0),.5,fixed=True), sphere((0.2,0.0,1.01),.5), ])
 O.bodies.append(pack.regularHexa(pack.inAlignedBox((0,0,0),(10,10,1)),radius=.5,gap=0,fixed=True))
 O.bodies.append(pack.regularOrtho(pack.inAlignedBox((3,3,3),(7,7,4)),radius=.05,gap=0))
 O.engines=[
@@ -13,7 +13,7 @@ O.engines=[
 	),
 	NewtonIntegrator(damping=0.4,gravity=[0,0,-10]),
 ]
-O.dt=.6*utils.PWaveTimeStep()
+O.dt=.6*PWaveTimeStep()
 O.saveTmp()
 #O.step()
 #while True:
