@@ -97,7 +97,6 @@ class FunctorWrapper //: public Serializable // FIXME functor shouldn't be seria
 {
 	private : 
 		typedef Loki::FunctorImpl<ResultType, ArgumentTypeList > Impl;
-		typedef ArgumentTypeList ParmList;
 		typedef typename Impl::Parm1 Parm1;
 		typedef typename Impl::Parm2 Parm2;
 		typedef typename Impl::Parm3 Parm3;
@@ -149,10 +148,5 @@ class FunctorWrapper //: public Serializable // FIXME functor shouldn't be seria
 		return (string(#class1)+" "+string(#class2));					\
 	}											\
 
-#define DEFINE_FUNCTOR_ORDER_3D(class1,class2,class3)						\
-	public : virtual std::string checkOrder() const						\
-	{											\
-		return (string(#class1)+" "+string(#class2)+" "+string(#class3));		\
-	}											\
 
 
