@@ -11,7 +11,9 @@
 #include <CGAL/Exact_predicates_inexact_constructions_kernel.h>
 #include <CGAL/Cartesian.h>
 #include <CGAL/Regular_triangulation_3.h>
-#include <CGAL/Regular_triangulation_euclidean_traits_3.h>
+#if CGAL_VERSION_NR < CGAL_VERSION_NUMBER(4,11,0)
+	#include <CGAL/Regular_triangulation_euclidean_traits_3.h>
+#endif
 #define ALPHASHAPES
 #ifdef ALPHASHAPES
 	#include <CGAL/Alpha_shape_vertex_base_3.h>
@@ -36,7 +38,12 @@ typedef CGAL::Exact_predicates_inexact_constructions_kernel K;
 //A bit faster, but gives crash eventualy
 // typedef CGAL::Cartesian<double> K;
 
-typedef CGAL::Regular_triangulation_euclidean_traits_3<K>   				Traits;
+#if CGAL_VERSION_NR < CGAL_VERSION_NUMBER(4,11,0)
+typedef CGAL::Regular_triangulation_euclidean_traits_3<K>				Traits;
+#else
+typedef K										Traits;
+#endif
+
 typedef K::Point_3									Point;
 typedef Traits::Vector_3 								CVector;
 typedef Traits::Segment_3								Segment;
@@ -44,8 +51,13 @@ typedef Traits::Segment_3								Segment;
 /** compilation inside yade: check that Real in yade is the same as Real we will define; otherwise it might make things go wrong badly (perhaps) **/
 BOOST_STATIC_ASSERT(sizeof(Traits::RT)==sizeof(Real));
 #endif
+#if CGAL_VERSION_NR < CGAL_VERSION_NUMBER(4,11,0)
 typedef Traits::RT									Real; //Dans cartesian, RT = FT
 typedef Traits::Weighted_point								Sphere;
+#else
+typedef Traits::FT									Real; //Dans cartesian, RT = FT
+typedef Traits::Weighted_point_3							Sphere;
+#endif
 typedef Traits::Plane_3									Plane;
 typedef Traits::Triangle_3								Triangle;
 typedef Traits::Tetrahedron_3								Tetrahedron;
@@ -57,7 +69,7 @@ class SimpleCellInfo : public Point {
 	unsigned int id;
 	Real s;
 	bool isFictious;//true if the cell has at least one fictious bounding sphere as a vertex
-	SimpleCellInfo (void) {isFictious=false; s=0;}
+	SimpleCellInfo (void) {isFictious=false; s=0;Point::operator= (CGAL::ORIGIN);}
 	SimpleCellInfo& setPoint(const Point &p) { Point::operator= (p); return *this; }
 	SimpleCellInfo& setScalar(const Real &scalar) { s=scalar; return *this; }
 	inline Real x (void) {return Point::x();}
@@ -96,8 +108,15 @@ class TriangulationTypes {
 public:
 typedef vertex_info								Vertex_Info;
 typedef cell_info								Cell_Info;
+#if CGAL_VERSION_NR < CGAL_VERSION_NUMBER(4,11,0)
 typedef CGAL::Triangulation_vertex_base_with_info_3<Vertex_Info, Traits>	Vb_info;
 typedef CGAL::Triangulation_cell_base_with_info_3<Cell_Info, Traits>		Cb_info;
+#else
+typedef CGAL::Regular_triangulation_vertex_base_3<K>				Vb0;
+typedef CGAL::Regular_triangulation_cell_base_3<K>				Rcb;
+typedef CGAL::Triangulation_vertex_base_with_info_3<Vertex_Info, Traits, Vb0>	Vb_info;
+typedef CGAL::Triangulation_cell_base_with_info_3<Cell_Info, Traits, Rcb>	Cb_info;
+#endif
 #ifdef ALPHASHAPES
 typedef CGAL::Alpha_shape_vertex_base_3<Traits,Vb_info> Vb;
 typedef CGAL::Alpha_shape_cell_base_3<Traits,Cb_info>   Fb;
@@ -132,3 +151,12 @@ typedef typename RTriangulation::Finite_edges_iterator				FiniteEdgesIterator;
 typedef TriangulationTypes<SimpleVertexInfo,SimpleCellInfo>			SimpleTriangulationTypes;
 
 } // namespace CGT
+
+typedef CGT::CVector CVector;
+typedef CGT::Point Point;
+
+/// Converters for Eigen and CGAL vectors
+inline CVector makeCgVect ( const Vector3r& yv ) {return CVector ( yv[0],yv[1],yv[2] );}
+inline Point makeCgPoint ( const Vector3r& yv ) {return Point ( yv[0],yv[1],yv[2] );}
+inline Vector3r makeVector3r ( const Point& yv ) {return Vector3r ( yv[0],yv[1],yv[2] );}
+inline Vector3r makeVector3r ( const CVector& yv ) {return Vector3r ( yv[0],yv[1],yv[2] );}
