@@ -1,4 +1,4 @@
-#include <string.h>
+#include <string>
 #include "Timer.h"
 
 Real_timer::Real_timer() : T1(0), T2(0), elapsed(0.0), started(0.0), interv(0), running(true)
