@@ -57,8 +57,6 @@ void ZECollider::action(){
 		periodic=scene->isPeriodic;
 	}
 
-		findBoundDispatcherInEnginesIfNoFunctorsAndWarn();
-
 		if(verletDist<0){
 			Real minR=std::numeric_limits<Real>::infinity();
 			FOREACH(const shared_ptr<Body>& b, *scene->bodies){
@@ -68,7 +66,7 @@ void ZECollider::action(){
 				minR=min(s->radius,minR);
 			}
 			// if no spheres, disable stride
-			verletDist=isinf(minR) ? 0 : std::abs(verletDist)*minR;
+			verletDist=std::isinf(minR) ? 0 : std::abs(verletDist)*minR;
 		}
 		
 		// update bounds via boundDispatcher
