@@ -27,7 +27,7 @@ bool Law2_ScGeom_JCFpmPhys_JointedCohesiveFrictionalPM::go(shared_ptr<IGeom>& ig
 	/// Defines the interparticular distance used for computation
 	Real D = 0;
 
-	/*this is for setting the equilibrium distance between all cohesive elements in the first contact detection*/
+	/*this is for setting the equilibrium distance between all cohesive elements at the first contact detection*/
 	if ( contact->isFresh(scene) ) { 
 	  phys->normalForce = Vector3r::Zero(); 
 	  phys->shearForce = Vector3r::Zero();
@@ -49,7 +49,7 @@ bool Law2_ScGeom_JCFpmPhys_JointedCohesiveFrictionalPM::go(shared_ptr<IGeom>& ig
 	      phys->isCohesive =0;
 	      phys->FnMax = 0;
 	      phys->FsMax = 0;
-	      return true; // do we need this? -> yes if it ends the loop (avoid the following calculations)
+	      return true;
 	      }
 	  } else { 
 	    D = phys->initD - std::abs((b1->state->pos - b2->state->pos).dot(phys->jointNormal)); 
@@ -61,7 +61,7 @@ bool Law2_ScGeom_JCFpmPhys_JointedCohesiveFrictionalPM::go(shared_ptr<IGeom>& ig
 	phys->crackJointAperture = D<0? -D : 0.; // for DFNFlow
 
 	/* Determination of interaction */
-	if (D < 0) { //spheres do not touch 
+	if (D < 0) { //tensile configuration
 	  if ( !phys->isCohesive) {
 	    if (!neverErase) return false;
 	    else {
@@ -70,48 +70,55 @@ bool Law2_ScGeom_JCFpmPhys_JointedCohesiveFrictionalPM::go(shared_ptr<IGeom>& ig
 	      phys->isCohesive =0;
 	      phys->FnMax = 0;
 	      phys->FsMax = 0;
-	      return true; // do we need this? not sure -> yes, it ends the loop (avoid the following calculations)
+	      return true;
 	    }
 	  }
 	  
 	  if ( phys->isCohesive && (phys->FnMax>0) && (std::abs(D)>Dtensile) ) {
 	    
-	    // update body state with the number of broken bonds
+	    nbTensCracks++;
+	    phys->isCohesive = 0;
+	    phys->FnMax = 0;
+	    phys->FsMax = 0;
+	    /// Do we need both the following lines?
+	    phys->breakOccurred = true;  // flag to trigger remesh for DFNFlowEngine
+	    phys->isBroken = true; // flag for DFNFlowEngine
+	    
+            // update body state with the number of broken bonds -> do we really need that?
 	    JCFpmState* st1=dynamic_cast<JCFpmState*>(b1->state.get());
 	    JCFpmState* st2=dynamic_cast<JCFpmState*>(b2->state.get());
-	    st1->tensBreak+=1;
-	    st2->tensBreak+=1;
-	    st1->tensBreakRel+=1.0/st1->noIniLinks;
-	    st2->tensBreakRel+=1.0/st2->noIniLinks;
+            st1->nbBrokenBonds++;
+	    st2->nbBrokenBonds++;
+	    st1->damageIndex+=1.0/st1->nbInitBonds;
+	    st2->damageIndex+=1.0/st2->nbInitBonds;
+            
+            Real scalarNF=phys->normalForce.norm();
+	    Real scalarSF=phys->shearForce.norm();
+	    totalTensCracksE+=0.5*( ((scalarNF*scalarNF)/phys->kn) + ((scalarSF*scalarSF)/phys->ks) );
+            totalCracksSurface += phys->crossSection;
 	    
-    	    // create a text file to record properties of the broken bond (iteration, position, type (tensile), cross section and contact normal orientation)
 	    if (recordCracks){
-	      std::ofstream file (fileCracks.c_str(), !cracksFileExist ? std::ios::trunc : std::ios::app);
-	      if(file.tellp()==0){ file <<"i p0 p1 p2 t s norm0 norm1 norm2"<<endl; }
-	      Vector3r crackNormal=Vector3r::Zero();
-	      if ((smoothJoint) && (phys->isOnJoint)) { crackNormal=phys->jointNormal; } else {crackNormal=geom->normal;}
-	      file << boost::lexical_cast<string> ( scene->iter )<<" "<< boost::lexical_cast<string> ( geom->contactPoint[0] ) <<" "<< boost::lexical_cast<string> ( geom->contactPoint[1] ) <<" "<< boost::lexical_cast<string> ( geom->contactPoint[2] ) <<" "<< 0 <<" "<< boost::lexical_cast<string> ( 0.5*(geom->radius1+geom->radius2) ) <<" "<< boost::lexical_cast<string> ( crackNormal[0] ) <<" "<< boost::lexical_cast<string> ( crackNormal[1] ) <<" "<< boost::lexical_cast<string> ( crackNormal[2] ) << endl;
+                std::ofstream file (fileCracks.c_str(), !cracksFileExist ? std::ios::trunc : std::ios::app);
+                if(file.tellp()==0){ file <<"iter time p0 p1 p2 type size norm0 norm1 norm2 nrg"<<endl; }
+                Vector3r crackNormal=Vector3r::Zero();
+                if ((smoothJoint) && (phys->isOnJoint)) { crackNormal=phys->jointNormal; } else {crackNormal=geom->normal;}
+                file << boost::lexical_cast<string> ( scene->iter ) << " " << boost::lexical_cast<string> ( scene->time ) <<" "<< boost::lexical_cast<string> ( geom->contactPoint[0] ) <<" "<< boost::lexical_cast<string> ( geom->contactPoint[1] ) <<" "<< boost::lexical_cast<string> ( geom->contactPoint[2] ) <<" "<< 1 <<" "<< boost::lexical_cast<string> ( 0.5*(geom->radius1+geom->radius2) ) <<" "<< boost::lexical_cast<string> ( crackNormal[0] ) <<" "<< boost::lexical_cast<string> ( crackNormal[1] ) <<" "<< boost::lexical_cast<string> ( crackNormal[2] ) <<" "<< boost::lexical_cast<string> ( 0.5*( ((scalarNF*scalarNF)/phys->kn) + ((scalarSF*scalarSF)/phys->ks) ) ) <<endl;
 	    }
 	    cracksFileExist=true;
-	    /// Timos
+            
 	    if (!neverErase) return false; 
 	    else {
 	      phys->shearForce = Vector3r::Zero();
 	      phys->normalForce = Vector3r::Zero();
-	      phys->isCohesive =0;
-	      phys->FnMax = 0;
-	      phys->FsMax = 0;
-	      phys->isBroken = true;
-	      return true; // do we need this? not sure -> yes, it ends the loop (avoid the following calculations)
+	      return true;
 	    }
-// 	    return true; // do we need this? no
 	  }
 	}
 	
 	/* NormalForce */
 	Real Fn = 0;
 	Fn = phys->kn*D; 
-
+        
 	/* ShearForce */
 	Vector3r& shearForce = phys->shearForce; 
 	Real jointSliding=0;
@@ -138,49 +145,79 @@ bool Law2_ScGeom_JCFpmPhys_JointedCohesiveFrictionalPM::go(shared_ptr<IGeom>& ig
 	/* Mohr-Coulomb criterion */
 	Real maxFs = phys->FsMax + Fn*phys->tanFrictionAngle;
 	Real scalarShearForce = shearForce.norm();
-	  
+               
 	if (scalarShearForce > maxFs) {
 	  if (scalarShearForce != 0)
 	    shearForce*=maxFs/scalarShearForce;
 	  else
 	    shearForce=Vector3r::Zero();
 	  if ((smoothJoint) && (phys->isOnJoint)) {phys->dilation=phys->jointCumulativeSliding*phys->tanDilationAngle-D; phys->initD+=(jointSliding*phys->tanDilationAngle);}
-	  // take into account shear cracking -> are those lines critical? -> TODO testing with and without
+
+// 	  if (!phys->isCohesive) {
+//             nbSlips++;
+//             totalSlipE+=((1./phys->ks)*(trialForce-shearForce))/*plastic disp*/.dot(shearForce)/*active force*/;
+//             
+// 	    if ( (recordSlips) && (maxFs!=0) ) {
+// 	    std::ofstream file (fileCracks.c_str(), !cracksFileExist ? std::ios::trunc : std::ios::app);
+// 	    if(file.tellp()==0){ file <<"iter time p0 p1 p2 type size norm0 norm1 norm2 nrg"<<endl; }
+// 	    Vector3r crackNormal=Vector3r::Zero();
+// 	    if ((smoothJoint) && (phys->isOnJoint)) { crackNormal=phys->jointNormal; } else {crackNormal=geom->normal;}
+// 	    file << boost::lexical_cast<string> ( scene->iter ) <<" " << boost::lexical_cast<string> ( scene->time ) <<" "<< boost::lexical_cast<string> ( geom->contactPoint[0] ) <<" "<< boost::lexical_cast<string> ( geom->contactPoint[1] ) <<" "<< boost::lexical_cast<string> ( geom->contactPoint[2] ) <<" "<< 0 <<" "<< boost::lexical_cast<string> ( 0.5*(geom->radius1+geom->radius2) ) <<" "<< boost::lexical_cast<string> ( crackNormal[0] ) <<" "<< boost::lexical_cast<string> ( crackNormal[1] ) <<" "<< boost::lexical_cast<string> ( crackNormal[2] ) <<" "<< boost::lexical_cast<string> ( ((1./phys->ks)*(trialForce-shearForce)).dot(shearForce) ) << endl;
+// 	    }
+// 	    cracksFileExist=true;    
+// 	  }
+
 	  if ( phys->isCohesive ) { 
 
-	    // update body state with the number of broken bonds
-	    JCFpmState* st1=dynamic_cast<JCFpmState*>(b1->state.get());
-	    JCFpmState* st2=dynamic_cast<JCFpmState*>(b2->state.get());
-	    st1->shearBreak+=1;
-	    st2->shearBreak+=1;
-	    st1->shearBreakRel+=1.0/st1->noIniLinks;
-	    st2->shearBreakRel+=1.0/st2->noIniLinks;
-
-	    // create a text file to record properties of the broken bond (iteration, position, type (shear), cross section and contact normal orientation)
-	    if (recordCracks){
-	      std::ofstream file (fileCracks.c_str(), !cracksFileExist ? std::ios::trunc : std::ios::app);
-	      if(file.tellp()==0){ file <<"i p0 p1 p2 t s norm0 norm1 norm2"<<endl; }
-	      Vector3r crackNormal=Vector3r::Zero();
-	      if ((smoothJoint) && (phys->isOnJoint)) { crackNormal=phys->jointNormal; } else {crackNormal=geom->normal;}
-	      file << boost::lexical_cast<string> ( scene->iter )<<" "<< boost::lexical_cast<string> ( geom->contactPoint[0] ) <<" "<< boost::lexical_cast<string> ( geom->contactPoint[1] ) <<" "<< boost::lexical_cast<string> ( geom->contactPoint[2] ) <<" "<< 1 <<" "<< boost::lexical_cast<string> ( 0.5*(geom->radius1+geom->radius2) ) <<" "<< boost::lexical_cast<string> ( crackNormal[0] ) <<" "<< boost::lexical_cast<string> ( crackNormal[1] ) <<" "<< boost::lexical_cast<string> ( crackNormal[2] ) << endl;
-	    }
-	    cracksFileExist=true;
-	    
-	    // set the contact properties to friction if in compression, delete contact if in tension
-	    phys->isBroken = true;
+	    nbShearCracks++;
 	    phys->isCohesive = 0;
 	    phys->FnMax = 0;
 	    phys->FsMax = 0;
-// 	    shearForce *= Fn*phys->tanFrictionAngle/scalarShearForce; // now or at the next timestep?
-	    if ( D < 0 ) { // spheres do not touch
-	      if (!neverErase) return false;
-	      else {
-		phys->shearForce = Vector3r::Zero();
-		phys->normalForce = Vector3r::Zero();
-		return true; // do we need this? not sure -> yes, it ends the loop (avoid the following calculations)
-	      }
+	    /// Do we need both the following lines?
+	    phys->breakOccurred = true;  // flag to trigger remesh for DFNFlowEngine
+	    phys->isBroken = true; // flag for DFNFlowEngine
+	    
+	    // update body state with the number of broken bonds -> do we really need that?
+	    JCFpmState* st1=dynamic_cast<JCFpmState*>(b1->state.get());
+	    JCFpmState* st2=dynamic_cast<JCFpmState*>(b2->state.get());
+	    st1->nbBrokenBonds++;
+	    st2->nbBrokenBonds++;
+	    st1->damageIndex+=1.0/st1->nbInitBonds;
+	    st2->damageIndex+=1.0/st2->nbInitBonds;
+          
+	    Real scalarNF=phys->normalForce.norm();
+	    Real scalarSF=phys->shearForce.norm();
+	    totalShearCracksE+=0.5*( ((scalarNF*scalarNF)/phys->kn) + ((scalarSF*scalarSF)/phys->ks) );
+            totalCracksSurface += phys->crossSection;
+    
+	    if (recordCracks){
+	      std::ofstream file (fileCracks.c_str(), !cracksFileExist ? std::ios::trunc : std::ios::app);
+	      if(file.tellp()==0){ file <<"iter time p0 p1 p2 type size norm0 norm1 norm2 nrg"<<endl; }
+	      Vector3r crackNormal=Vector3r::Zero();
+	      if ((smoothJoint) && (phys->isOnJoint)) { crackNormal=phys->jointNormal; } else {crackNormal=geom->normal;}
+	      file << boost::lexical_cast<string> ( scene->iter ) << " " << boost::lexical_cast<string> ( scene->time ) <<" "<< boost::lexical_cast<string> ( geom->contactPoint[0] ) <<" "<< boost::lexical_cast<string> ( geom->contactPoint[1] ) <<" "<< boost::lexical_cast<string> ( geom->contactPoint[2] ) <<" "<< 2 <<" "<< boost::lexical_cast<string> ( 0.5*(geom->radius1+geom->radius2) ) <<" "<< boost::lexical_cast<string> ( crackNormal[0] ) <<" "<< boost::lexical_cast<string> ( crackNormal[1] ) <<" "<< boost::lexical_cast<string> ( crackNormal[2] ) <<" "<< boost::lexical_cast<string> ( 0.5*( ((scalarNF*scalarNF)/phys->kn) + ((scalarSF*scalarSF)/phys->ks) ) ) <<endl;
 	    }
-// 	    return true; // do we need this one? no
+	    cracksFileExist=true;
+	    
+// 	    // option 1: delete contact whatsoever (if in compression, it will be detected as a new contact at the next timestep -> actually, not necesarily because of the near neighbour interaction: there could be a gap between the bonded particles and thus a broken contact may not be frictional at the next timestep if the detection is done for strictly contacting particles...) -> to TEST
+//             if (!neverErase) return false;
+//             else {
+//                 phys->shearForce = Vector3r::Zero();
+// 		phys->normalForce = Vector3r::Zero();
+// 		return true;
+//             }
+            
+            // option 2: delete contact if in tension
+//	    shearForce *= Fn*phys->tanFrictionAngle/scalarShearForce; // now or at the next timestep? should not be very different -> to TEST
+	    if ( D < 0 ) { // spheres do not touch
+                if (!neverErase) return false;
+                else {
+                    phys->shearForce = Vector3r::Zero();
+                    phys->normalForce = Vector3r::Zero();
+                    return true;
+                }
+	    }
+	    
 	  }
 	}
 	
@@ -228,6 +265,8 @@ void Ip2_JCFpmMat_JCFpmMat_JCFpmPhys::go(const shared_ptr<Material>& b1, const s
 	Real v2 	= yade2->poisson;
 	Real f1 	= yade1->frictionAngle;
 	Real f2 	= yade2->frictionAngle;
+        Real rf1 	= yade1->residualFrictionAngle>=0? yade1->residualFrictionAngle: yade1->frictionAngle;
+	Real rf2 	= yade2->residualFrictionAngle>=0? yade2->residualFrictionAngle: yade2->frictionAngle;
 	Real SigT1	= yade1->tensileStrength;
 	Real SigT2	= yade2->tensileStrength;
 	Real Coh1	= yade1->cohesion;
@@ -240,26 +279,30 @@ void Ip2_JCFpmMat_JCFpmMat_JCFpmPhys::go(const shared_ptr<Material>& b1, const s
 
 	/* Pass values to JCFpmPhys. In case of a "jointed" interaction, the following values will be replaced by other ones later (in few if(){} blocks)*/
 	
-	// frictional properties
+	// elastic properties
 	contactPhysics->kn = 2.*E1*R1*E2*R2/(E1*R1+E2*R2);
-	if ( (v1==0)&&(v2==0) )
-	  contactPhysics->ks = 0;
-	else
-	  contactPhysics->ks = 2.*E1*R1*v1*E2*R2*v2/(E1*R1*v1+E2*R2*v2);
-	contactPhysics->tanFrictionAngle = std::tan(std::min(f1,f2));
+        ( (v1==0)&&(v2==0) )? contactPhysics->ks=0 : contactPhysics->ks = 2.*E1*R1*v1*E2*R2*v2/(E1*R1*v1+E2*R2*v2);
 	
 	// cohesive properties
 	///to set if the contact is cohesive or not
 	if ( ((cohesiveTresholdIteration < 0) || (scene->iter < cohesiveTresholdIteration)) && (std::min(SigT1,SigT2)>0 || std::min(Coh1,Coh2)>0) && (yade1->type == yade2->type)){ 
 	  contactPhysics->isCohesive=true;
-	  st1->noIniLinks++;
-	  st2->noIniLinks++;
+	  st1->nbInitBonds++;
+	  st2->nbInitBonds++;
 	}
 	
 	if ( contactPhysics->isCohesive ) {
 	  contactPhysics->FnMax = std::min(SigT1,SigT2)*contactPhysics->crossSection;
 	  contactPhysics->FsMax = std::min(Coh1,Coh2)*contactPhysics->crossSection;
 	}
+	// do we need that?
+// 	else {
+// 	  contactPhysics->FnMax = 0.;
+// 	  contactPhysics->FsMax = 0.;
+// 	}
+	
+        // frictional properties      
+        contactPhysics->isCohesive? contactPhysics->tanFrictionAngle = std::tan(std::min(f1,f2)) : contactPhysics->tanFrictionAngle = std::tan(std::min(rf1,rf2));
 
 	/// +++ Jointed interactions ->NOTE: geom->normal is oriented from 1 to 2 / jointNormal from plane to sphere 
 	if ( st1->onJoint && st2->onJoint )
@@ -308,15 +351,15 @@ void Ip2_JCFpmMat_JCFpmMat_JCFpmPhys::go(const shared_ptr<Material>& b1, const s
 		  
 			///to set if the contact is cohesive or not
 			if ( ((cohesiveTresholdIteration < 0) || (scene->iter < cohesiveTresholdIteration)) && (std::min(jcoh1,jcoh2)>0 || std::min(jSigT1,jSigT2)>0) ) {
-			  contactPhysics->isCohesive=true;
-			  st1->noIniLinks++;
-			  st2->noIniLinks++;
+                            contactPhysics->isCohesive=true;
+                            st1->nbInitBonds++;
+                            st2->nbInitBonds++;
 			} 
 			else { contactPhysics->isCohesive=false; contactPhysics->FnMax=0; contactPhysics->FsMax=0; }
 		  
 			if ( contactPhysics->isCohesive ) {
-				contactPhysics->FnMax = std::min(jSigT1,jSigT2)*contactPhysics->crossSection;
-				contactPhysics->FsMax = std::min(jcoh1,jcoh2)*contactPhysics->crossSection;
+                            contactPhysics->FnMax = std::min(jSigT1,jSigT2)*contactPhysics->crossSection;
+                            contactPhysics->FsMax = std::min(jcoh1,jcoh2)*contactPhysics->crossSection;
 			}
 	}
 	interaction->phys = contactPhysics;
