@@ -5,6 +5,7 @@
 *  This program is free software; it is licensed under the terms of the  *
 *  GNU General Public License v2 or later. See file LICENSE for details. *
 *************************************************************************/
+#ifdef YADE_CGAL
 
 #pragma once
 
@@ -64,4 +65,4 @@ class MicroMacroAnalyser : public GlobalEngine
 
 REGISTER_SERIALIZABLE(MicroMacroAnalyser);
 
-
+#endif /* YADE_CGAL */
