@@ -124,9 +124,13 @@ class Shop{
 
 		//! Compute the stress tensor in each defined cell, return a stress tensor depth profile
 		static py::tuple getStressProfile(Real volume, int nCell, Real dz, Real zRef, vector<Real> vPartAverageX, vector<Real> vPartAverageY, vector<Real> vPartAverageZ);
+		static py::tuple getStressProfile_contact(Real volume, int nCell, Real dz, Real zRef);	//same, only contact contribution
+
+                //! Compute average depth profile of particle velocity (x,y,z) and solid volume fraction. The direction may be specified by direction argument (default is z).
+                static py::tuple getDepthProfiles(Real vCell, int nCell, Real dz, Real zRef,bool activateCond=false, Real radiusPy=0,int direction=2);
+		//! Same, but taking into account point particles
+		static py::tuple getDepthProfiles_center(Real vCell, int nCell, Real dz, Real zRef,bool activateCond=false, Real radiusPy=0);
 
-		//! Compute average depth profile of particle velocity (x,y,z) and solid volume fraction
-		static py::tuple getDepthProfiles(Real vCell, int nCell, Real dz, Real zRef,bool activateCond=false, Real radiusPy=0);
 
 		//! Compute overall ("macroscopic") stress of periodic cell, returning 2 tensors
 		//! (contribution of normal and shear forces)
