@@ -475,8 +475,91 @@ py::tuple Shop::getStressProfile(Real volume, int nCell, Real dz, Real zRef, vec
 	return py::make_tuple(stressTensorProfile,kineticStressTensorProfile,granularTemperatureProfile);
 }
 
+py::tuple Shop::getStressProfile_contact(Real volume, int nCell, Real dz, Real zRef){
+	int minZ=0;
+	int maxZ=0;
+	Real minPosZ=0.;
+	Real maxPosZ=0.;
+	Scene* scene=Omega::instance().getScene().get();
+	vector<Matrix3r> stressTensorProfile(nCell,Matrix3r::Zero());
+	vector<Real> numPart(nCell,0.0);
 
-py::tuple Shop::getDepthProfiles(Real vCell, int nCell, Real dz, Real zRef,bool activateCond, Real radiusPy){
+	const bool isPeriodic = scene->isPeriodic;
+	//
+	//Love Weber contribution (same as getStress(), but with different layers)
+	//
+	FOREACH(const shared_ptr<Interaction>&I,  *scene->interactions){	// loop over the interactions 
+                if (!I->isReal()) continue;
+		shared_ptr<Body> b1 = Body::byId(I->getId1(),scene);
+		shared_ptr<Body> b2 = Body::byId(I->getId2(),scene);
+
+		if ((b1->state->blockedDOFs!=State::DOF_ALL)||(b2->state->blockedDOFs!=State::DOF_ALL)){// to remove annoying contribution from the fixed particles
+			//Layers in which the particle center is contained
+			int Np1 = floor((b1->state->pos[2] - zRef)/dz);
+			int Np2 = floor((b2->state->pos[2] - zRef)/dz);
+			//Vector between the two centers, from 2 to 1
+			Vector3r branch = b1->state->pos -b2->state->pos;
+			if (isPeriodic) branch -= scene->cell->hSize*I->cellDist.cast<Real>();//to handle periodicity
+				
+			//Contact vector (from 1 to 2)
+			NormShearPhys* nsi=YADE_CAST<NormShearPhys*> ( I->phys.get() );
+			Vector3r fContact = nsi->normalForce + nsi->shearForce;
+
+			//The contribution to the stress tensor is taken such that only the part of the branch vector 
+			//inside the cell is taken into account
+			//If the whole vector is in the cell, add the whole contribution to the cell
+			if (Np1==Np2){
+				if ((Np1>=0) && (Np1<nCell)){ 
+					stressTensorProfile[Np1]+= 1/volume*fContact*branch.transpose();
+				}
+			}
+			//Otherwise, find out the cell crossed by the branch vector and assign it the contribution from this part. 
+			else {	
+				//Find which one is above the other to prepare the loop
+				if (Np1>Np2){
+					minZ = Np2;
+					minPosZ = b2->state->pos[2]-zRef;
+					maxZ = Np1;
+					maxPosZ = b1->state->pos[2]-zRef;
+				}
+				else if (Np2>Np1) {
+					minZ = Np1;
+					minPosZ = b1->state->pos[2]-zRef;
+					maxZ = Np2;
+					maxPosZ = b2->state->pos[2]-zRef;
+				}
+		
+				Real branchS_x = pow(branch[0],2.0);
+				Real branchS_y = pow(branch[1],2.0);
+				Real branchS_z = pow(branch[2],2.0);
+
+				//Normalize the branch vector
+				branch/=sqrt(branchS_x + branchS_y+branchS_z);
+
+				//Loop over the cell containing the branch vector
+				int numLayer = minZ;
+				while (numLayer<=maxZ){
+					if ((numLayer>= 0)&&(numLayer<nCell)){
+						//Evaluate the branch height inside the cell
+						Real deltaZ = dz;
+						if (numLayer==minZ) deltaZ = dz - (minPosZ - minZ*dz);
+						else if (numLayer==maxZ) deltaZ = maxPosZ - maxZ*dz;
+						//From it, trigonometry gives us the vector contained in the cell
+						Vector3r branchVectCell = deltaZ*sqrt(1.0 + 1.0/branchS_z*(branchS_x + branchS_y))*branch;
+						//Add the contribution to the stress tensor
+						stressTensorProfile[numLayer]+= 1.0/volume*fContact*branchVectCell.transpose();
+					}
+					//Increment the layer/cell number
+					numLayer+=1;
+						
+				}
+			}
+		}
+	}
+	return py::make_tuple(stressTensorProfile);
+}
+
+py::tuple Shop::getDepthProfiles(Real vCell, int nCell, Real dz, Real zRef,bool activateCond, Real radiusPy, int dir){
 	//Initialization
 	int minZ;
 	int maxZ;
@@ -498,7 +581,7 @@ py::tuple Shop::getDepthProfiles(Real vCell, int nCell, Real dz, Real zRef,bool
 			const Sphere* sphere = dynamic_cast<Sphere*>(b->shape.get());
 			if (sphere->radius!=radiusPy) continue;
 		} //select diameters asked
-		const Real zPos = b->state->pos[2]-zRef;
+                const Real zPos = b->state->pos[dir]-zRef;
 		int Np = floor(zPos/dz);	//Define the layer number with 0 corresponding to zRef. Let the z position wrt to zero, that way all z altitude are positive. (otherwise problem with volPart evaluation)
 
 		minZ= floor((zPos-s->radius)/dz);
@@ -544,6 +627,52 @@ py::tuple Shop::getDepthProfiles(Real vCell, int nCell, Real dz, Real zRef,bool
 }
 
 
+// Same as getDepthProfiles but taking into account the particles as a point
+py::tuple Shop::getDepthProfiles_center(Real vCell, int nCell, Real dz, Real zRef,bool activateCond, Real radiusPy){
+	//Initialization
+	Real volPart;
+
+	vector<Real> velAverageX(nCell,0.0);
+        vector<Real> velAverageY(nCell,0.0);
+        vector<Real> velAverageZ(nCell,0.0);
+	vector<Real> phiAverage(nCell,0.0);
+	vector<Real> Npart(nCell,0.0);
+
+	//Loop over the particles
+	FOREACH(const shared_ptr<Body>& b, *Omega::instance().getScene()->bodies){
+		shared_ptr<Sphere> s=YADE_PTR_DYN_CAST<Sphere>(b->shape); if(!s) continue;
+		if (activateCond==true){
+			const Sphere* sphere = dynamic_cast<Sphere*>(b->shape.get());
+			if (sphere->radius!=radiusPy) continue;
+		} //select diameters asked
+		const Real zPos = b->state->pos[2]-zRef;
+		int Np = floor(zPos/dz);	//Define the layer number with 0 corresponding to zRef. Let the z position wrt to zero, that way all z altitude are positive. (otherwise problem with volPart evaluation)
+
+		if ((Np>=0)&&(Np<nCell)){
+			volPart =4./3.* Mathr::PI*pow(s->radius,3);
+			phiAverage[Np]+=volPart/vCell;
+			Npart[Np]+=1.;
+			velAverageX[Np]+=b->state->vel[0];
+		        velAverageY[Np]+=b->state->vel[1];
+		        velAverageZ[Np]+=b->state->vel[2];
+		}
+	}
+	//Normalized the weighted velocity by the volume of particles contained inside the cell
+	for(int n=0;n<nCell;n++){
+		if (Npart[n]!=0){
+			velAverageX[n]/=Npart[n];
+                        velAverageY[n]/=Npart[n];
+                        velAverageZ[n]/=Npart[n];
+		}
+		else {
+			velAverageX[n] = 0.0;
+                        velAverageY[n] = 0.0;
+                        velAverageZ[n] = 0.0;
+		}
+	}
+	return py::make_tuple(phiAverage,velAverageX,velAverageY,velAverageZ);
+}
+
 
 Matrix3r Shop::getCapillaryStress(Real volume, bool mindlin){
 	Scene* scene=Omega::instance().getScene().get();
@@ -644,8 +773,16 @@ void Shop::growParticles(Real multiplier, bool updateMass, bool dynamicOnly)
 		//We grow only spheres and clumps 
 		if(b->isClump() or sphereIdx == b->shape->getClassIndex()){			
 			if (updateMass) {b->state->mass*=pow(multiplier,3); b->state->inertia*=pow(multiplier,5);}
-			// for clumps we updated inertia, nothing else to do
-			if (b->isClump()) continue;
+			if (b->isClump())  {
+				//update local Se3 of each clump member
+				//FIXME: the velocity of clump members is invalid after a growth since the growth is not reflected (see Clump::moveMembers)
+				// for clumps we updated inertia, nothing else to do
+				FOREACH(Clump::MemberMap::value_type& B, YADE_PTR_CAST<Clump>(b->shape)->members){
+					// B.first is Body::id_t, B.second is local Se3r of that body in the clump
+					B.second.position *= multiplier;}
+				// for clumps we are done
+				continue;
+			}
 			// for spheres, we update radius
 			(YADE_CAST<Sphere*> (b->shape.get()))->radius *= multiplier;
 			// and if they are clump members,clump volume variation with homothetic displacement of all members
