@@ -41,6 +41,8 @@
 #include <lib/serialization/ObjectIO.hpp>
 #include <csignal>
 
+#include <pkg/common/KinematicEngines.hpp>
+
 namespace py = boost::python;
 
 /*
@@ -125,7 +127,7 @@ class pyBodyContainer{
 		const shared_ptr<Clump> clump(YADE_PTR_CAST<Clump>(clumpBody->shape));
 		if (clump->members.size()==1 ){
 			Clump::del(clumpBody,memberBody); //phD was not commented out
-			for (int i=0; i<clump->ids.size(); i++){
+			for (unsigned i=0; i<clump->ids.size(); i++){
 				if (clump->ids[i] == memberBody->getId()){
 					clump->ids.erase(clump->ids.begin()+i);
 				}
@@ -135,7 +137,7 @@ class pyBodyContainer{
 			
 		}else{
 			Clump::del(clumpBody,memberBody); //pHD was not commented out
-			for (int i=0; i<clump->ids.size(); i++){
+			for (unsigned i=0; i<clump->ids.size(); i++){
 				if (clump->ids[i] == memberBody->getId()){
 					clump->ids.erase(clump->ids.begin()+i);
 				}
@@ -564,6 +566,10 @@ class pyOmega{
 			if(coll){ _DO_FUNCTORS(coll->boundDispatcher->functors,BoundFunctor); }
 			#undef _DO_FUNCTORS
 			#undef _TRY_DISPATCHER
+			CombinedKinematicEngine* cke=dynamic_cast<CombinedKinematicEngine*>(e.get());
+			if (cke) {
+				FOREACH(const shared_ptr<KinematicEngine>& ke, cke->comb){ if(!ke->label.empty()){ pyRunString("__builtins__."+ke->label+"=Omega().labeledEngine('"+ke->label+"')"); } }
+			}
 		}
 	}
 	py::object labeled_engine_get(string label){
@@ -582,6 +588,10 @@ class pyOmega{
 			if(coll){ _DO_FUNCTORS(coll->boundDispatcher->functors,BoundFunctor); }
 			#undef _DO_FUNCTORS
 			#undef _TRY_DISPATCHER
+			CombinedKinematicEngine* cke=dynamic_cast<CombinedKinematicEngine*>(e.get());
+			if (cke) {
+				FOREACH(const shared_ptr<KinematicEngine>& ke, cke->comb){ if(ke->label==label) return py::object(ke); }
+			}
 		}
 		throw std::invalid_argument(string("No engine labeled `")+label+"'");
 	}
